# Changelog

## cmdtools v2.4.9

### Changes from commit

- use `__` prefix and suffix for aliases property by @hugebrain16 [#fd5df39](https://github.com/HugeBrain16/cmdtools/commit/fd5df392c59ffec7898278b01cbc4ba9e680d380)
- use default args instead of using Arbitrary Keyword Argument by @hugebrain16 [#02c9d8f](https://github.com/HugeBrain16/cmdtools/commit/02c9d8fa7b4c7d207df0c30cb8e056f6fd327ec0)
